@@ -1,16 +1,20 @@
+from __future__ import annotations
+
 """
 N-Triples RDF graph serializer for RDFLib.
 See <http://www.w3.org/TR/rdf-testcases/#ntriples> for details about the
 format.
 """
-from typing import IO, Optional
+import codecs
+import warnings
+from typing import IO, TYPE_CHECKING, Optional, Tuple, Union
 
 from rdflib.graph import Graph
-from rdflib.term import Literal
 from rdflib.serializer import Serializer
+from rdflib.term import Literal
 
-import warnings
-import codecs
+if TYPE_CHECKING:
+    from rdflib.graph import _TripleType
 
 __all__ = ["NTSerializer"]
 
@@ -29,7 +33,7 @@ class NTSerializer(Serializer):
         base: Optional[str] = None,
         encoding: Optional[str] = "utf-8",
         **args,
-    ):
+    ) -> None:
         if base is not None:
             warnings.warn("NTSerializer does not support base.")
         if encoding != "utf-8":
@@ -40,7 +44,6 @@ class NTSerializer(Serializer):
 
         for triple in self.store:
             stream.write(_nt_row(triple).encode())
-        stream.write("\n".encode())
 
 
 class NT11Serializer(NTSerializer):
@@ -54,18 +57,20 @@ class NT11Serializer(NTSerializer):
         Serializer.__init__(self, store)  # default to utf-8
 
 
-def _nt_row(triple):
+def _nt_row(triple: _TripleType) -> str:
     if isinstance(triple[2], Literal):
         return "%s %s %s .\n" % (
-            triple[0].n3(),
-            triple[1].n3(),
+            # type error: "Node" has no attribute "n3"
+            triple[0].n3(),  # type: ignore[attr-defined]
+            triple[1].n3(),  # type: ignore[attr-defined]
             _quoteLiteral(triple[2]),
         )
     else:
-        return "%s %s %s .\n" % (triple[0].n3(), triple[1].n3(), triple[2].n3())
+        # type error: "Node" has no attribute "n3"
+        return "%s %s %s .\n" % (triple[0].n3(), triple[1].n3(), triple[2].n3())  # type: ignore[attr-defined]
 
 
-def _quoteLiteral(l_):
+def _quoteLiteral(l_: Literal) -> str:  # noqa: N802
     """
     a simpler version of term.Literal.n3()
     """
@@ -82,13 +87,15 @@ def _quoteLiteral(l_):
         return "%s" % encoded
 
 
-def _quote_encode(l_):
+def _quote_encode(l_: str) -> str:
     return '"%s"' % l_.replace("\\", "\\\\").replace("\n", "\\n").replace(
         '"', '\\"'
     ).replace("\r", "\\r")
 
 
-def _nt_unicode_error_resolver(err):
+def _nt_unicode_error_resolver(
+    err: UnicodeError,
+) -> Tuple[Union[str, bytes], int]:
     """
     Do unicode char replaces as defined in https://www.w3.org/TR/2004/REC-rdf-testcases-20040210/#ntrip_strings
     """
@@ -98,8 +105,12 @@ def _nt_unicode_error_resolver(err):
         fmt = "\\u%04X" if c <= 0xFFFF else "\\U%08X"
         return fmt % c
 
-    string = err.object[err.start : err.end]
-    return "".join(_replace_single(c) for c in string), err.end
+    # type error: "UnicodeError" has no attribute "object"
+    # type error: "UnicodeError" has no attribute "start"
+    # type error: "UnicodeError" has no attribute "end"
+    string = err.object[err.start : err.end]  # type: ignore[attr-defined]
+    # type error: "UnicodeError" has no attribute "end"
+    return "".join(_replace_single(c) for c in string), err.end  # type: ignore[attr-defined]
 
 
 codecs.register_error("_rdflib_nt_escape", _nt_unicode_error_resolver)
