@@ -1,21 +1,25 @@
 # -*- coding: UTF-8 -*-
+from __future__ import annotations
 
-import re
-import json
 import itertools
+import json
+import re
+from typing import Any, Dict, List, Tuple
 
 import pytest
+
 from rdflib import Graph
-from rdflib.plugin import register, Serializer
+from rdflib.plugin import register
+from rdflib.serializer import Serializer
 
 register("json-ld", Serializer, "rdflib.plugins.serializers.jsonld", "JsonLDSerializer")
 
 
-cases = []
+cases: List[Tuple[str, Dict[str, Any]]] = []
 
 
-def case(*args):
-    cases.append(args)
+def case(source: str, data: Dict[str, Any]):
+    cases.append((source, data))
 
 
 case(
