@@ -1,14 +1,16 @@
-from os import environ, chdir, getcwd, path as p
 import json
+from os import chdir, environ, getcwd
+from os import path as p
+from typing import Tuple
 
 import pytest
+
 import rdflib
-import rdflib.plugins.parsers.jsonld as parser
 from rdflib.term import URIRef
+
 from . import runner
 
-
-unsupported_tests = ("frame", "normalize")
+unsupported_tests: Tuple[str, ...] = ("frame", "normalize")
 unsupported_tests += (
     "error",
     "remote",
@@ -81,9 +83,7 @@ def get_test_suite_cases(skip_known_bugs=True):
     skiptests = unsupported_tests
     if skip_known_bugs:
         skiptests += known_bugs
-    for cat, num, inputpath, expectedpath, context, options in read_manifest(
-        skiptests
-    ):
+    for cat, num, inputpath, expectedpath, context, options in read_manifest(skiptests):
         if inputpath.endswith(".jsonld"):  # toRdf
             if expectedpath.endswith(".jsonld"):  # compact/expand/flatten
                 func = runner.do_test_json
@@ -92,9 +92,7 @@ def get_test_suite_cases(skip_known_bugs=True):
         else:  # fromRdf
             func = runner.do_test_serializer
         # func.description = "%s-%s-%s" % (group, case)
-        rdf_test_uri = URIRef("{0}{1}-manifest.jsonld#t{2}".format(
-            TC_BASE, cat, num
-        ))
+        rdf_test_uri = URIRef("{0}{1}-manifest.jsonld#t{2}".format(TC_BASE, cat, num))
         yield rdf_test_uri, func, TC_BASE, cat, num, inputpath, expectedpath, context, options
 
 
@@ -116,5 +114,15 @@ def global_state():
     "rdf_test_uri, func, suite_base, cat, num, inputpath, expectedpath, context, options",
     get_test_suite_cases(),
 )
-def test_suite(rdf_test_uri: URIRef, func, suite_base, cat, num, inputpath, expectedpath, context, options):
+def test_suite(
+    rdf_test_uri: URIRef,
+    func,
+    suite_base,
+    cat,
+    num,
+    inputpath,
+    expectedpath,
+    context,
+    options,
+):
     func(suite_base, cat, num, inputpath, expectedpath, context, options)
